==> kubernetes-model-apiextensions-6.4.0-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceDefinitionStatusFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface CustomResourceDefinitionStatusFluent<A extends CustomResourceDefinitionStatusFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAcceptedNames instead.
   * @return The buildable object.
   */
  @Deprecated
  public CustomResourceDefinitionNames getAcceptedNames();
  public CustomResourceDefinitionNames buildAcceptedNames();
  public A withAcceptedNames(CustomResourceDefinitionNames acceptedNames);
  public Boolean hasAcceptedNames();
  public CustomResourceDefinitionStatusFluent.AcceptedNamesNested<A> withNewAcceptedNames();
  public CustomResourceDefinitionStatusFluent.AcceptedNamesNested<A> withNewAcceptedNamesLike(CustomResourceDefinitionNames item);
  public CustomResourceDefinitionStatusFluent.AcceptedNamesNested<A> editAcceptedNames();
  public CustomResourceDefinitionStatusFluent.AcceptedNamesNested<A> editOrNewAcceptedNames();
  public CustomResourceDefinitionStatusFluent.AcceptedNamesNested<A> editOrNewAcceptedNamesLike(CustomResourceDefinitionNames item);
  public A addToConditions(Integer index,CustomResourceDefinitionCondition item);
  public A setToConditions(Integer index,CustomResourceDefinitionCondition item);
  public A addToConditions(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionCondition... items);
  public A addAllToConditions(Collection<CustomResourceDefinitionCondition> items);
  public A removeFromConditions(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionCondition... items);
  public A removeAllFromConditions(Collection<CustomResourceDefinitionCondition> items);
  public A removeMatchingFromConditions(Predicate<CustomResourceDefinitionConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<CustomResourceDefinitionCondition> getConditions();
  public List<CustomResourceDefinitionCondition> buildConditions();
  public CustomResourceDefinitionCondition buildCondition(Integer index);
  public CustomResourceDefinitionCondition buildFirstCondition();
  public CustomResourceDefinitionCondition buildLastCondition();
  public CustomResourceDefinitionCondition buildMatchingCondition(Predicate<CustomResourceDefinitionConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<CustomResourceDefinitionConditionBuilder> predicate);
  public A withConditions(List<CustomResourceDefinitionCondition> conditions);
  public A withConditions(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionCondition... conditions);
  public Boolean hasConditions();
  public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type);
  public CustomResourceDefinitionStatusFluent.ConditionsNested<A> addNewCondition();
  public CustomResourceDefinitionStatusFluent.ConditionsNested<A> addNewConditionLike(CustomResourceDefinitionCondition item);
  public CustomResourceDefinitionStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,CustomResourceDefinitionCondition item);
  public CustomResourceDefinitionStatusFluent.ConditionsNested<A> editCondition(Integer index);
  public CustomResourceDefinitionStatusFluent.ConditionsNested<A> editFirstCondition();
  public CustomResourceDefinitionStatusFluent.ConditionsNested<A> editLastCondition();
  public CustomResourceDefinitionStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<CustomResourceDefinitionConditionBuilder> predicate);
  public A addToStoredVersions(Integer index,String item);
  public A setToStoredVersions(Integer index,String item);
  public A addToStoredVersions(java.lang.String... items);
  public A addAllToStoredVersions(Collection<String> items);
  public A removeFromStoredVersions(java.lang.String... items);
  public A removeAllFromStoredVersions(Collection<String> items);
  public List<String> getStoredVersions();
  public String getStoredVersion(Integer index);
  public String getFirstStoredVersion();
  public String getLastStoredVersion();
  public String getMatchingStoredVersion(Predicate<String> predicate);
  public Boolean hasMatchingStoredVersion(Predicate<String> predicate);
  public A withStoredVersions(List<String> storedVersions);
  public A withStoredVersions(java.lang.String... storedVersions);
  public Boolean hasStoredVersions();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface AcceptedNamesNested<N> extends Nested<N>,CustomResourceDefinitionNamesFluent<CustomResourceDefinitionStatusFluent.AcceptedNamesNested<N>>{
    public N and();
    public N endAcceptedNames();
    
  }
  public interface ConditionsNested<N> extends Nested<N>,CustomResourceDefinitionConditionFluent<CustomResourceDefinitionStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}

==> kubernetes-model-apiextensions-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceDefinitionStatusFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface CustomResourceDefinitionStatusFluent<A extends CustomResourceDefinitionStatusFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAcceptedNames instead.
   * @return The buildable object.
   */
  @Deprecated
  public CustomResourceDefinitionNames getAcceptedNames();
  public CustomResourceDefinitionNames buildAcceptedNames();
  public A withAcceptedNames(CustomResourceDefinitionNames acceptedNames);
  public Boolean hasAcceptedNames();
  public CustomResourceDefinitionStatusFluent.AcceptedNamesNested<A> withNewAcceptedNames();
  public CustomResourceDefinitionStatusFluent.AcceptedNamesNested<A> withNewAcceptedNamesLike(CustomResourceDefinitionNames item);
  public CustomResourceDefinitionStatusFluent.AcceptedNamesNested<A> editAcceptedNames();
  public CustomResourceDefinitionStatusFluent.AcceptedNamesNested<A> editOrNewAcceptedNames();
  public CustomResourceDefinitionStatusFluent.AcceptedNamesNested<A> editOrNewAcceptedNamesLike(CustomResourceDefinitionNames item);
  public A addToConditions(int index,CustomResourceDefinitionCondition item);
  public A setToConditions(int index,CustomResourceDefinitionCondition item);
  public A addToConditions(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionCondition... items);
  public A addAllToConditions(Collection<CustomResourceDefinitionCondition> items);
  public A removeFromConditions(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionCondition... items);
  public A removeAllFromConditions(Collection<CustomResourceDefinitionCondition> items);
  public A removeMatchingFromConditions(Predicate<CustomResourceDefinitionConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<CustomResourceDefinitionCondition> getConditions();
  public List<CustomResourceDefinitionCondition> buildConditions();
  public CustomResourceDefinitionCondition buildCondition(int index);
  public CustomResourceDefinitionCondition buildFirstCondition();
  public CustomResourceDefinitionCondition buildLastCondition();
  public CustomResourceDefinitionCondition buildMatchingCondition(Predicate<CustomResourceDefinitionConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<CustomResourceDefinitionConditionBuilder> predicate);
  public A withConditions(List<CustomResourceDefinitionCondition> conditions);
  public A withConditions(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionCondition... conditions);
  public Boolean hasConditions();
  public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type);
  public CustomResourceDefinitionStatusFluent.ConditionsNested<A> addNewCondition();
  public CustomResourceDefinitionStatusFluent.ConditionsNested<A> addNewConditionLike(CustomResourceDefinitionCondition item);
  public CustomResourceDefinitionStatusFluent.ConditionsNested<A> setNewConditionLike(int index,CustomResourceDefinitionCondition item);
  public CustomResourceDefinitionStatusFluent.ConditionsNested<A> editCondition(int index);
  public CustomResourceDefinitionStatusFluent.ConditionsNested<A> editFirstCondition();
  public CustomResourceDefinitionStatusFluent.ConditionsNested<A> editLastCondition();
  public CustomResourceDefinitionStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<CustomResourceDefinitionConditionBuilder> predicate);
  public A addToStoredVersions(int index,String item);
  public A setToStoredVersions(int index,String item);
  public A addToStoredVersions(java.lang.String... items);
  public A addAllToStoredVersions(Collection<String> items);
  public A removeFromStoredVersions(java.lang.String... items);
  public A removeAllFromStoredVersions(Collection<String> items);
  public List<String> getStoredVersions();
  public String getStoredVersion(int index);
  public String getFirstStoredVersion();
  public String getLastStoredVersion();
  public String getMatchingStoredVersion(Predicate<String> predicate);
  public Boolean hasMatchingStoredVersion(Predicate<String> predicate);
  public A withStoredVersions(List<String> storedVersions);
  public A withStoredVersions(java.lang.String... storedVersions);
  public Boolean hasStoredVersions();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface AcceptedNamesNested<N> extends Nested<N>,CustomResourceDefinitionNamesFluent<CustomResourceDefinitionStatusFluent.AcceptedNamesNested<N>>{
    public N and();
    public N endAcceptedNames();
    
  }
  public interface ConditionsNested<N> extends Nested<N>,CustomResourceDefinitionConditionFluent<CustomResourceDefinitionStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}
